## 0.0.40

This new version introduces the addition of a new dependency to the project, enhancing its functionality.

### New Features

- Added the frozenlist package to the dependencies list in pyproject.toml to support immutable lists in the project (a7d069) (Eric Ma)

### Bug Fixes

- None in this release.

### Deprecations

- None in this release.
